@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2019,2021-2022 Aurimas Cernius
+ * Copyright (C) 2010-2019,2021-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -125,10 +125,6 @@ public:
     {
       return m_action_manager;
     }
-  virtual IconManager & icon_manager() override
-    {
-      return m_icon_manager;
-    }
   virtual notebooks::NotebookManager & notebook_manager() override;
   virtual sync::SyncManager & sync_manager() override
     {
@@ -161,7 +157,7 @@ public:
     {
       return !is_background();
     }
-  virtual void open_note(const Note::Ptr & note) override;
+  void open_note(const NoteBase & note) override;
 protected:
   virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line) override;
   virtual void on_startup() override;
@@ -182,7 +178,6 @@ private:
   void register_object();
 
   NoteManager *m_manager;
-  IconManager m_icon_manager;
   Preferences m_preferences;
   ActionManager m_action_manager;
   sync::SyncManager *m_sync_manager;
@@ -190,7 +185,7 @@ private:
   bool m_is_background;
   bool m_is_shell_search;
   RemoteControlProxy m_remote_control;
-  PreferencesDialog *m_prefsdlg;
+  std::unique_ptr<PreferencesDialog> m_prefsdlg;
   GnoteCommandLine m_cmd_line;
   sync::SyncDialog::Ptr m_sync_dlg;
 };
