@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2020,2022-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -49,9 +49,9 @@ const Glib::ustring & NoteDataBufferSynchronizerBase::text()
   return data().text();
 }
 
-void NoteDataBufferSynchronizerBase::set_text(const Glib::ustring & t)
+void NoteDataBufferSynchronizerBase::set_text(Glib::ustring && t)
 {
-  data().text() = t;
+  data().text() = std::move(t);
 }
 
 
@@ -83,10 +83,39 @@ std::vector<Glib::ustring> NoteBase::parse_tags(const xmlNodePtr tagnodes)
   return tags;
 }
 
+Glib::ustring NoteBase::parse_text_content(const Glib::ustring & content)
+{
+  xmlDocPtr doc = xmlParseDoc((const xmlChar*)content.c_str());
+  if(!doc) {
+    return "";
+  }
 
-NoteBase::NoteBase(const Glib::ustring & filepath, NoteManagerBase & _manager)
+  Glib::ustring ret;
+  sharp::XmlReader reader(doc);
+  while(reader.read()) {
+    switch(reader.get_node_type()) {
+    case XML_READER_TYPE_ELEMENT:
+      if(reader.get_name() == "list-item") {
+        ret += "\n";
+      }
+      break;
+    case XML_READER_TYPE_TEXT:
+    case XML_READER_TYPE_WHITESPACE:
+    case XML_READER_TYPE_SIGNIFICANT_WHITESPACE:
+      ret += reader.get_value();
+      break;
+    default:
+      break;
+    }
+  }
+
+  return ret;
+}
+
+
+NoteBase::NoteBase(const Glib::ustring && filepath, NoteManagerBase & _manager)
   : m_manager(_manager)
-  , m_file_path(filepath)
+  , m_file_path(std::move(filepath))
   , m_enabled(true)
 {
 }
@@ -112,16 +141,16 @@ const Glib::ustring & NoteBase::get_title() const
   return data_synchronizer().data().title();
 }
 
-void NoteBase::set_title(const Glib::ustring & new_title)
+void NoteBase::set_title(Glib::ustring && new_title)
 {
-  set_title(new_title, false);
+  set_title(std::move(new_title), false);
 }
 
-void NoteBase::set_title(const Glib::ustring & new_title, bool from_user_action)
+void NoteBase::set_title(Glib::ustring && new_title, bool from_user_action)
 {
   if(data_synchronizer().data().title() != new_title) {
-    Glib::ustring old_title = data_synchronizer().data().title();
-    data_synchronizer().data().title() = new_title;
+    Glib::ustring old_title = std::move(data_synchronizer().data().title());
+    data_synchronizer().data().title() = std::move(new_title);
 
     if(from_user_action) {
       process_rename_link_update(old_title);
@@ -135,25 +164,21 @@ void NoteBase::set_title(const Glib::ustring & new_title, bool from_user_action)
 
 void NoteBase::process_rename_link_update(const Glib::ustring & old_title)
 {
-  NoteBase::List linking_notes = m_manager.get_notes_linking_to(old_title);
-  const NoteBase::Ptr self = shared_from_this();
-
-  if(!linking_notes.empty()) {
-    for(NoteBase::Ptr & note : linking_notes) {
-      note->rename_links(old_title, self);
-      signal_renamed(shared_from_this(), old_title);
-      queue_save(CONTENT_CHANGED);
-    }
+  for(NoteBase::Ptr & note : m_manager.get_notes_linking_to(old_title)) {
+    note->rename_links(old_title, *this);
   }
+
+  signal_renamed(shared_from_this(), old_title);
+  queue_save(CONTENT_CHANGED);
 }
 
-void NoteBase::rename_without_link_update(const Glib::ustring & newTitle)
+void NoteBase::rename_without_link_update(Glib::ustring && newTitle)
 {
   if(data_synchronizer().data().title() != newTitle) {
-    data_synchronizer().data().title() = newTitle;
+    data_synchronizer().data().title() = std::move(newTitle);
 
     // HACK:
-    signal_renamed(shared_from_this(), newTitle);
+    signal_renamed(shared_from_this(), data_synchronizer().data().title());
 
     queue_save(CONTENT_CHANGED); // TODO: Right place for this?
   }
@@ -198,17 +223,17 @@ void NoteBase::save()
   signal_saved(shared_from_this());
 }
 
-void NoteBase::rename_links(const Glib::ustring & old_title, const Ptr & renamed)
+void NoteBase::rename_links(const Glib::ustring & old_title, const NoteBase & renamed)
 {
   handle_link_rename(old_title, renamed, true);
 }
 
-void NoteBase::remove_links(const Glib::ustring & old_title, const Ptr & renamed)
+void NoteBase::remove_links(const Glib::ustring & old_title, const NoteBase & renamed)
 {
   handle_link_rename(old_title, renamed, false);
 }
 
-void NoteBase::handle_link_rename(const Glib::ustring &, const Ptr &, bool)
+void NoteBase::handle_link_rename(const Glib::ustring &, const NoteBase &, bool)
 {
 }
 
@@ -283,9 +308,14 @@ Glib::ustring NoteBase::get_complete_note_xml()
   return m_manager.note_archiver().write_string(data_synchronizer().synchronized_data());
 }
 
-void NoteBase::set_xml_content(const Glib::ustring & xml)
+void NoteBase::set_xml_content(Glib::ustring && xml)
 {
-  data_synchronizer().set_text(xml);
+  data_synchronizer().set_text(std::move(xml));
+}
+
+Glib::ustring NoteBase::text_content()
+{
+  return parse_text_content(xml_content());
 }
 
 void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, ChangeType changeType)
