@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -217,8 +217,8 @@ public:
 
   virtual void queue_save(ChangeType c);
   virtual void save();
-  void rename_links(const Glib::ustring & old_title, const Ptr & renamed);
-  void remove_links(const Glib::ustring & old_title, const Ptr & renamed);
+  void rename_links(const Glib::ustring & old_title, const NoteBase & renamed);
+  void remove_links(const Glib::ustring & old_title, const NoteBase & renamed);
   virtual void delete_note();
   void add_tag(const Tag::Ptr &);
   virtual void remove_tag(Tag &);
@@ -251,22 +251,22 @@ public:
     }
   virtual void enabled(bool is_enabled);
 
-  typedef sigc::signal<void, const NoteBase::Ptr &> SavedHandler;
+  typedef sigc::signal<void(const NoteBase::Ptr &)> SavedHandler;
   SavedHandler signal_saved;
-  typedef sigc::signal<void, const NoteBase::Ptr&, const Glib::ustring& > RenamedHandler;
+  typedef sigc::signal<void(const NoteBase::Ptr&, const Glib::ustring&)> RenamedHandler;
   RenamedHandler signal_renamed;
-  typedef sigc::signal<void, const NoteBase&, const Tag::Ptr&> TagAddedHandler;
+  typedef sigc::signal<void(const NoteBase&, const Tag::Ptr&)> TagAddedHandler;
   TagAddedHandler signal_tag_added;
-  typedef sigc::signal<void, const NoteBase&, const Tag &> TagRemovingHandler;  
+  typedef sigc::signal<void(const NoteBase&, const Tag &)> TagRemovingHandler;
   TagRemovingHandler signal_tag_removing;
-  typedef sigc::signal<void, const NoteBase::Ptr&, const Glib::ustring&> TagRemovedHandler;
+  typedef sigc::signal<void(const NoteBase::Ptr&, const Glib::ustring&)> TagRemovedHandler;
   TagRemovedHandler signal_tag_removed;
 protected:
   virtual const NoteDataBufferSynchronizerBase & data_synchronizer() const = 0;
   virtual NoteDataBufferSynchronizerBase & data_synchronizer() = 0;
   virtual void process_rename_link_update(const Glib::ustring & old_title);
   void set_change_type(ChangeType c);
-  virtual void handle_link_rename(const Glib::ustring & old_title, const Ptr & renamed, bool rename);
+  virtual void handle_link_rename(const Glib::ustring & old_title, const NoteBase & renamed, bool rename);
 private:
   NoteManagerBase & m_manager;
   Glib::ustring m_file_path;
