@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2015,2017,2019 Aurimas Cernius
+ * Copyright (C) 2011-2015,2017,2019,2021-2022 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -23,16 +23,12 @@
 
 #include <glibmm/i18n.h>
 #include <glibmm/stringutils.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/separatormenuitem.h>
 #include <gtkmm/treeiter.h>
 #include <gtkmm/treemodel.h>
-#include <gtkmm/uimanager.h>
 
 #include "sharp/string.hpp"
 #include "notebooks/notebookapplicationaddin.hpp"
 #include "notebooks/notebookmanager.hpp"
-#include "notebooks/notebooknewnotemenuitem.hpp"
 #include "notebooks/notebook.hpp"
 #include "iactionmanager.hpp"
 #include "ignote.hpp"
@@ -94,7 +90,7 @@ namespace gnote {
 
     void NotebookApplicationAddin::on_new_notebook_action(const Glib::VariantBase&)
     {
-      NotebookManager::prompt_create_new_notebook(ignote(), NULL);
+      NotebookManager::prompt_create_new_notebook(ignote(), ignote().get_main_window());
     }
 
 
