@@ -37,7 +37,7 @@ namespace gnote {
     : public NoteManagerBase
   {
   public:
-    typedef sigc::slot<void, const Note::Ptr &> NoteChangedSlot;
+    typedef sigc::slot<void(const Note::Ptr &)> NoteChangedSlot;
     
     NoteManager(IGnote & g);
     virtual ~NoteManager();
