@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2015,2017,2019-2021 Aurimas Cernius
+ * Copyright (C) 2011-2015,2017,2019-2022 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -42,7 +42,7 @@
     { \
       return m_##key; \
     } \
-  sigc::signal<void> signal_##key##_changed;
+  sigc::signal<void()> signal_##key##_changed;
 
 
 #define GNOTE_PREFERENCES_CACHING_SETTING(key, type) \
@@ -64,10 +64,7 @@ namespace gnote {
     GNOTE_PREFERENCES_CACHING_SETTING(enable_wikiwords, bool)
     GNOTE_PREFERENCES_CACHING_SETTING(enable_custom_font, bool)
     GNOTE_PREFERENCES_SETTING_BOOL(enable_auto_bulleted_lists)
-    GNOTE_PREFERENCES_SETTING_BOOL(enable_close_note_on_escape)
     GNOTE_PREFERENCES_CACHING_SETTING(note_rename_behavior, int)
-    GNOTE_PREFERENCES_CACHING_SETTING(open_notes_in_new_window, bool)
-    GNOTE_PREFERENCES_SETTING_BOOL(autosize_note_window)
     GNOTE_PREFERENCES_SETTING_STRING(start_note_uri)
     GNOTE_PREFERENCES_CACHING_SETTING(custom_font_face, const Glib::ustring &)
     GNOTE_PREFERENCES_SETTING_STRING(menu_pinned_notes)
