@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2016,2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2012-2014,2016,2017,2019-2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,9 +22,10 @@
 
 #include <glibmm/i18n.h>
 #include <glibmm/main.h>
-#include <gtkmm/radiobutton.h>
+#include <gtkmm/columnview.h>
 #include <gtkmm/scrolledwindow.h>
-#include <gtkmm/treeview.h>
+#include <gtkmm/singleselection.h>
+#include <gtkmm/signallistitemfactory.h>
 
 #include "ignote.hpp"
 #include "iconmanager.hpp"
@@ -40,18 +41,51 @@ namespace sync {
 
 namespace {
 
-class TreeViewModel
-  : public Gtk::TreeModelColumnRecord
+struct ListRow
 {
-public:
-  TreeViewModel()
-    {
-      add(m_col1);
-      add(m_col2);
-    }
+  Glib::ustring title;
+  Glib::ustring status;
+};
 
-    Gtk::TreeModelColumn<Glib::ustring> m_col1;
-    Gtk::TreeModelColumn<Glib::ustring> m_col2;
+typedef utils::ModelRecord<ListRow> ListRecord;
+
+
+class ColFactory
+  : public utils::LabelFactory
+{
+protected:
+  Glib::ustring get_text(Gtk::ListItem & item) override
+  {
+    auto record = std::dynamic_pointer_cast<ListRecord>(item.get_item());
+    return get_text(*record);
+  }
+  virtual Glib::ustring get_text(ListRecord & record) = 0;
+  void set_text(Gtk::Label & label, const Glib::ustring & text) override
+  {
+    label.set_text(text);
+  }
+};
+
+
+class Col1Factory
+  : public ColFactory
+{
+protected:
+  Glib::ustring get_text(ListRecord & record) override
+  {
+    return record.value.title;
+  }
+};
+
+
+class Col2Factory
+  : public ColFactory
+{
+protected:
+  Glib::ustring get_text(ListRecord & record) override
+  {
+    return record.value.status;
+  }
 };
 
 
@@ -72,73 +106,67 @@ public:
         suggestedRename = suggestedRenameBase + " " + TO_STRING(i);
       }
 
-      Gtk::Grid *outerVBox = manage(new Gtk::Grid);
+      Gtk::Grid *outerVBox = Gtk::make_managed<Gtk::Grid>();
       outerVBox->set_row_spacing(8);
-      outerVBox->set_border_width(12);
+      outerVBox->set_margin(12);
 
-      Gtk::Grid *hbox = manage(new Gtk::Grid);
+      Gtk::Grid *hbox = Gtk::make_managed<Gtk::Grid>();
       hbox->set_column_spacing(8);
-      Gtk::Image *image = manage(new Gtk::Image);
-      image->set_from_icon_name("dialog-warning", Gtk::IconSize(Gtk::ICON_SIZE_DIALOG));
-      image->show();
+      Gtk::Image *image = Gtk::make_managed<Gtk::Image>();
+      image->set_from_icon_name("dialog-warning");
       hbox->attach(*image, 0, 0, 1, 1);
 
-      Gtk::Grid *vbox = manage(new Gtk::Grid);
+      Gtk::Grid *vbox = Gtk::make_managed<Gtk::Grid>();
       vbox->set_row_spacing(8);
 
-      m_header_label = manage(new Gtk::Label);
+      m_header_label = Gtk::make_managed<Gtk::Label>();
       m_header_label->set_use_markup(true);
       m_header_label->property_xalign() = 0;
       m_header_label->set_use_underline(false);
-      m_header_label->show();
       vbox->attach(*m_header_label, 0, 0, 1, 1);
 
-      m_message_label = manage(new Gtk::Label);
+      m_message_label = Gtk::make_managed<Gtk::Label>();
       m_message_label->property_xalign() = 0;
       m_message_label->set_use_underline(false);
-      m_message_label->set_line_wrap(true);
+      m_message_label->set_wrap(true);
       m_message_label->property_wrap() = true;
-      m_message_label->show();
       vbox->attach(*m_message_label, 0, 1, 1, 1);
 
-      vbox->show();
       vbox->set_hexpand(true);
       hbox->attach(*vbox, 1, 0, 1, 1);
 
-      hbox->show();
       outerVBox->attach(*hbox, 0, 0, 1, 1);
-      get_content_area()->pack_start(*outerVBox);
+      get_content_area()->append(*outerVBox);
 
-      Gtk::Grid *renameHBox = manage(new Gtk::Grid);
-      renameRadio = manage(new Gtk::RadioButton(m_radio_group, _("Rename local note:")));
+      Gtk::Grid *renameHBox = Gtk::make_managed<Gtk::Grid>();
+      renameRadio = Gtk::make_managed<Gtk::CheckButton>(_("Rename local note:"), true);
       renameRadio->signal_toggled().connect(sigc::mem_fun(*this, &SyncTitleConflictDialog::radio_toggled));
-      Gtk::Grid *renameOptionsVBox = manage(new Gtk::Grid);
+      Gtk::Grid *renameOptionsVBox = Gtk::make_managed<Gtk::Grid>();
 
-      renameEntry = manage(new Gtk::Entry);
+      renameEntry = Gtk::make_managed<Gtk::Entry>();
       renameEntry->set_text(suggestedRename);
       renameEntry->signal_changed().connect(sigc::mem_fun(*this, &SyncTitleConflictDialog::rename_entry_changed));
-      renameUpdateCheck = manage(new Gtk::CheckButton(_("Update links in referencing notes")));
+      renameUpdateCheck = Gtk::make_managed<Gtk::CheckButton>(_("Update links in referencing notes"), true);
       renameOptionsVBox->attach(*renameEntry, 0, 0, 1, 1);
       renameHBox->attach(*renameRadio, 0, 0, 1, 1);
       renameHBox->attach(*renameOptionsVBox, 1, 0, 1, 1);
-      get_content_area()->pack_start(*renameHBox);
+      get_content_area()->append(*renameHBox);
 
-      deleteExistingRadio = manage(new Gtk::RadioButton(m_radio_group, _("Overwrite local note")));
+      deleteExistingRadio = Gtk::make_managed<Gtk::CheckButton>(_("Overwrite local note"), true);
+      deleteExistingRadio->set_group(*renameRadio);
       deleteExistingRadio->signal_toggled().connect(sigc::mem_fun(*this, &SyncTitleConflictDialog::radio_toggled));
-      get_content_area()->pack_start(*deleteExistingRadio);
+      get_content_area()->append(*deleteExistingRadio);
 
-      alwaysDoThisCheck = manage(new Gtk::CheckButton(_("Always perform this action")));
-      get_content_area()->pack_start(*alwaysDoThisCheck);
+      alwaysDoThisCheck = Gtk::make_managed<Gtk::CheckButton>(_("Always perform this action"), true);
+      get_content_area()->append(*alwaysDoThisCheck);
 
-      continueButton = add_button(_("_Continue"), Gtk::RESPONSE_ACCEPT);
+      continueButton = add_button(_("_Continue"), Gtk::ResponseType::ACCEPT);
 
       // Set initial dialog text
       header_text(_("Note conflict detected"));
       message_text(Glib::ustring::compose(
         _("The server version of \"%1\" conflicts with your local note.  What do you want to do with your local note?"),
         existingNote->get_title()));
-
-      show_all();
     }
   void header_text(const Glib::ustring & value)
     {
@@ -203,10 +231,9 @@ private:
 
   Gtk::Entry *renameEntry;
   Gtk::CheckButton *renameUpdateCheck;
-  Gtk::RadioButton *renameRadio;
-  Gtk::RadioButton *deleteExistingRadio;
+  Gtk::CheckButton *renameRadio;
+  Gtk::CheckButton *deleteExistingRadio;
   Gtk::CheckButton *alwaysDoThisCheck;
-  Gtk::RadioButtonGroup m_radio_group;
 
   Gtk::Label *m_header_label;
   Gtk::Label *m_message_label;
@@ -231,134 +258,97 @@ SyncDialog::SyncDialog(IGnote & g, NoteManagerBase & manager)
   set_size_request(400, -1);
 
   // Outer box. Surrounds all of our content.
-  Gtk::Grid *outerVBox = manage(new Gtk::Grid);
+  Gtk::Grid *outerVBox = Gtk::make_managed<Gtk::Grid>();
   outerVBox->set_row_spacing(12);
-  outerVBox->set_border_width(6);
-  outerVBox->show();
+  outerVBox->set_margin(6);
+  outerVBox->set_expand(true);
   int outerVBoxRow = 0;
-  get_content_area()->pack_start(*outerVBox, true, true, 0);
+  get_content_area()->append(*outerVBox);
 
   // Top image and label
-  Gtk::Grid *hbox = manage(new Gtk::Grid);
+  Gtk::Grid *hbox = Gtk::make_managed<Gtk::Grid>();
   hbox->set_column_spacing(12);
-  hbox->show();
   outerVBox->attach(*hbox, 0, outerVBoxRow++, 1, 1);
 
-  m_image = manage(new Gtk::Image(g.icon_manager().get_icon(IconManager::GNOTE, 48)));
-  m_image->set_halign(Gtk::ALIGN_START);
-  m_image->set_valign(Gtk::ALIGN_START);
-  m_image->show();
+  m_image = Gtk::make_managed<Gtk::Image>();
+  m_image->set_from_icon_name(IconManager::GNOTE);
+  m_image->set_halign(Gtk::Align::START);
+  m_image->set_valign(Gtk::Align::START);
   hbox->attach(*m_image, 0, 0, 1, 1);
 
   // Label header and message
-  Gtk::Grid *vbox = manage(new Gtk::Grid);
+  Gtk::Grid *vbox = Gtk::make_managed<Gtk::Grid>();
   vbox->set_row_spacing(6);
-  vbox->show();
   vbox->set_hexpand(true);
   hbox->attach(*vbox, 1, 0, 1, 1);
 
-  m_header_label = manage(new Gtk::Label);
+  m_header_label = Gtk::make_managed<Gtk::Label>();
   m_header_label->set_use_markup(true);
-  m_header_label->set_halign(Gtk::ALIGN_START);
+  m_header_label->set_halign(Gtk::Align::START);
   m_header_label->set_use_underline(false);
-  m_header_label->set_line_wrap(true);
-  m_header_label->show();
+  m_header_label->set_wrap(true);
   vbox->attach(*m_header_label, 0, 0, 1, 1);
 
-  m_message_label = manage(new Gtk::Label);
-  m_message_label->set_halign(Gtk::ALIGN_START);
+  m_message_label = Gtk::make_managed<Gtk::Label>();
+  m_message_label->set_halign(Gtk::Align::START);
   m_message_label->set_use_underline(false);
-  m_message_label->set_line_wrap(true);
+  m_message_label->set_wrap(true);
   m_message_label->set_size_request(250, -1);
-  m_message_label->show();
   vbox->attach(*m_message_label, 0, 1, 1, 1);
 
-  m_progress_bar = manage(new Gtk::ProgressBar);
-  m_progress_bar->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+  m_progress_bar = Gtk::make_managed<Gtk::ProgressBar>();
+  m_progress_bar->set_orientation(Gtk::Orientation::HORIZONTAL);
   m_progress_bar->set_pulse_step(0.3);
-  m_progress_bar->show();
   outerVBox->attach(*m_progress_bar, 0, outerVBoxRow++, 1, 1);
 
-  m_progress_label = manage(new Gtk::Label);
+  m_progress_label = Gtk::make_managed<Gtk::Label>();
   m_progress_label->set_use_markup(true);
-  m_progress_label->set_halign(Gtk::ALIGN_START);
+  m_progress_label->set_halign(Gtk::Align::START);
   m_progress_label->set_use_underline(false);
-  m_progress_label->set_line_wrap(true);
+  m_progress_label->set_wrap(true);
   m_progress_label->property_wrap() = true;
-  m_progress_label->show();
   outerVBox->attach(*m_progress_label, 0, outerVBoxRow++, 1, 1);
 
-  // Expander containing TreeView
-  m_expander = manage(new Gtk::Expander(_("Details")));
-  m_expander->set_spacing(6);
+  // Expander containing table
+  m_expander = Gtk::make_managed<Gtk::Expander>(_("Details"));
+  m_expander->set_margin(6);
   g_signal_connect(m_expander->gobj(), "activate", G_CALLBACK(SyncDialog::on_expander_activated), this);
-  m_expander->show();
   m_expander->set_vexpand(true);
   outerVBox->attach(*m_expander, 0, outerVBoxRow++, 1, 1);
 
   // Contents of expander
-  Gtk::Grid *expandVBox = manage(new Gtk::Grid);
-  expandVBox->show();
-  m_expander->add(*expandVBox);
+  Gtk::Grid *expandVBox = Gtk::make_managed<Gtk::Grid>();
+  m_expander->set_child(*expandVBox);
 
-  // Scrolled window around TreeView
-  Gtk::ScrolledWindow *scrolledWindow = manage(new Gtk::ScrolledWindow);
-  scrolledWindow->set_shadow_type(Gtk::SHADOW_IN);
+  // Scrolled window around table
+  Gtk::ScrolledWindow *scrolledWindow = Gtk::make_managed<Gtk::ScrolledWindow>();
   scrolledWindow->set_size_request(-1, 200);
-  scrolledWindow->show();
   scrolledWindow->set_hexpand(true);
   scrolledWindow->set_vexpand(true);
   expandVBox->attach(*scrolledWindow, 0, 0, 1, 1);
 
-  // Create model for TreeView
-  // Work-around for GCC versions < 4.3 (http://gcc.gnu.org/bugs/#cxx_rvalbind)
-  TreeViewModel tmp_model;
-  m_model = Gtk::TreeStore::create(tmp_model);
+  m_model = Gio::ListStore<ListRecord>::create();
+  auto model = Gtk::SingleSelection::create(m_model);
 
-  // Create TreeView, attach model
-  Gtk::TreeView *treeView = manage(new Gtk::TreeView);
-  treeView->set_model(m_model);
-  treeView->signal_row_activated().connect(sigc::mem_fun(*this, &SyncDialog::on_row_activated));
-  treeView->show();
-  scrolledWindow->add(*treeView);
+  auto view = Gtk::make_managed<Gtk::ColumnView>(model);
+  view->signal_activate().connect(sigc::mem_fun(*this, &SyncDialog::on_row_activated));
+  scrolledWindow->set_child(*view);
 
-  // Set up TreeViewColumns
-  Gtk::CellRenderer *renderer = manage(new Gtk::CellRendererText);
-  Gtk::TreeViewColumn *column = manage(new Gtk::TreeViewColumn(_("Note Title"), *renderer));
-  column->set_sort_column(0);
+  // Set up columns
+  auto column = Gtk::ColumnViewColumn::create(_("Note Title"), Glib::make_refptr_for_instance(new Col1Factory));
   column->set_resizable(true);
-  column->set_cell_data_func(*renderer, sigc::mem_fun(*this, &SyncDialog::treeview_col1_data_func));
-  treeView->append_column(*column);
+  view->append_column(column);
 
-  renderer = manage(new Gtk::CellRendererText);
-  column = manage(new Gtk::TreeViewColumn(_("Status"), *renderer));
-  column->set_sort_column(1);
+  column = Gtk::ColumnViewColumn::create(_("Status"), Glib::make_refptr_for_instance(new Col2Factory));
   column->set_resizable(true);
-  treeView->append_column(*column);
-  column->set_cell_data_func(*renderer, sigc::mem_fun(*this, &SyncDialog::treeview_col2_data_func));
+  view->append_column(column);
 
   // Button to close dialog.
-  m_close_button = add_button(_("_Close"), static_cast<int>(Gtk::RESPONSE_CLOSE));
+  m_close_button = add_button(_("_Close"), static_cast<int>(Gtk::ResponseType::CLOSE));
   m_close_button->set_sensitive(false);
 }
 
 
-void SyncDialog::treeview_col1_data_func(Gtk::CellRenderer *renderer, const Gtk::TreeIter & iter)
-{
-  Glib::ustring text;
-  iter->get_value(0, text);
-  static_cast<Gtk::CellRendererText*>(renderer)->property_text() = text;
-}
-
-
-void SyncDialog::treeview_col2_data_func(Gtk::CellRenderer *renderer, const Gtk::TreeIter & iter)
-{
-  Glib::ustring text;
-  iter->get_value(1, text);
-  static_cast<Gtk::CellRendererText*>(renderer)->property_text() = text;
-}
-
-
 void SyncDialog::on_realize()
 {
   Gtk::Dialog::on_realize();
@@ -406,16 +396,15 @@ void SyncDialog::on_expander_activated(GtkExpander*, gpointer data)
 }
 
 
-void SyncDialog::on_row_activated(const Gtk::TreeModel::Path & path, Gtk::TreeViewColumn*)
+void SyncDialog::on_row_activated(guint idx)
 {
   // TODO: Store GUID hidden in model; use instead of title
-  Gtk::TreeIter iter = m_model->get_iter(path);
-  if(!iter) {
+  auto item = std::static_pointer_cast<Gio::ListStore<ListRecord>>(m_model)->get_item(idx);
+  if(!item) {
     return;
   }
 
-  Glib::ustring noteTitle;
-  iter->get_value(0, noteTitle);
+  Glib::ustring noteTitle = item->value.title;
 
   NoteBase::Ptr note = m_manager.find(noteTitle);
   if(note != 0) {
@@ -457,9 +446,8 @@ void SyncDialog::progress_text(const Glib::ustring & value)
 
 void SyncDialog::add_update_item(const Glib::ustring & title, Glib::ustring & status)
 {
-  Gtk::TreeIter iter = m_model->append();
-  iter->set_value(0, title);
-  iter->set_value(1 , status);
+  auto record = ListRecord::create({title, status});
+  m_model->append(record);
 }
 
 
@@ -484,7 +472,7 @@ void SyncDialog::sync_state_changed_(SyncState state)
     set_title(_("Synchronizing Notes"));
     header_text(_("Synchronizing your notes..."));
     message_text(_("This may take a while, kick back and enjoy!"));
-    m_model->clear();
+    m_model->remove_all();
     progress_text(_("Connecting to the server..."));
     m_progress_bar->set_fraction(0);
     m_progress_bar->show();
@@ -529,7 +517,7 @@ void SyncDialog::sync_state_changed_(SyncState state)
     break;
   case SUCCEEDED:
     {
-      int count = m_model->children().size();
+      int count = m_model->get_n_items();
       set_title(_("Synchronization Complete"));
       header_text(_("Synchronization is complete"));
       Glib::ustring numNotesUpdated = ngettext("%1 note updated.", "%1 notes updated.", count);
@@ -593,18 +581,26 @@ void SyncDialog::note_conflict_detected(const Note::Ptr & localConflictNote,
                                         const std::vector<Glib::ustring> & noteUpdateTitles)
 {
   int dlgBehaviorPref = m_gnote.preferences().sync_configured_conflict_behavior();
+  std::mutex wait_mutex;
+  std::condition_variable wait;
+  std::unique_lock lock(wait_mutex);
+  bool completed = false;
 
   // This event handler will be called by the synchronization thread
   // so we have to use the delegate here to manipulate the GUI.
   // To be consistent, any exceptions in the delgate will be caught
   // and then rethrown in the synchronization thread.
-  utils::main_context_call(
-    [this, localConflictNote, remoteNote, noteUpdateTitles, dlgBehaviorPref]() {
+  utils::main_context_invoke(
+    [this, localConflictNote, remoteNote, noteUpdateTitles, dlgBehaviorPref, &wait_mutex, &wait, &completed]() {
       note_conflict_detected_(localConflictNote, remoteNote, noteUpdateTitles,
                               static_cast<SyncTitleConflictResolution>(dlgBehaviorPref),
-                              OVERWRITE_EXISTING
+                              OVERWRITE_EXISTING, wait_mutex, wait, completed
       );
     });
+
+  while(!completed) {
+    wait.wait(lock);
+  }
 }
 
 
@@ -613,22 +609,57 @@ void SyncDialog::note_conflict_detected_(
   NoteUpdate remoteNote,
   const std::vector<Glib::ustring> & noteUpdateTitles,
   SyncTitleConflictResolution savedBehavior,
-  SyncTitleConflictResolution resolution)
+  SyncTitleConflictResolution resolution,
+  std::mutex &wait_mutex,
+  std::condition_variable &wait,
+  bool & completed)
 {
-  SyncTitleConflictDialog conflictDlg(localConflictNote, noteUpdateTitles);
-  Gtk::ResponseType reponse = Gtk::RESPONSE_OK;
-
   bool noteSyncBitsMatch = m_gnote.sync_manager().synchronized_note_xml_matches(
     localConflictNote->get_complete_note_xml(), remoteNote.m_xml_content);
 
   // If the synchronized note content is in conflict
   // and there is no saved conflict handling behavior, show the dialog
   if(!noteSyncBitsMatch && savedBehavior == 0) {
-    reponse = static_cast<Gtk::ResponseType>(conflictDlg.run());
+    auto conflictDlg = Gtk::make_managed<SyncTitleConflictDialog>(localConflictNote, noteUpdateTitles);
+    conflictDlg->signal_response()
+      .connect([this, conflictDlg, localConflictNote, remoteNote, savedBehavior, resolution, noteSyncBitsMatch, &wait_mutex, &wait, &completed](int resp) {
+      auto response = static_cast<Gtk::ResponseType>(resp);
+      conflict_dialog_response(
+        conflictDlg,
+        localConflictNote,
+        remoteNote,
+        savedBehavior,
+        resolution,
+        noteSyncBitsMatch,
+        response
+      );
+
+      std::unique_lock lock(wait_mutex);
+      completed = true;
+      wait.notify_one();
+    });
+    conflictDlg->show();
   }
+  else {
+    std::unique_lock lock(wait_mutex);
+    completed = true;
+    wait.notify_one();
+  }
+}
 
 
-  if(reponse == Gtk::RESPONSE_CANCEL) {
+void SyncDialog::conflict_dialog_response(
+  Gtk::Dialog *dialog,
+  const Note::Ptr & localConflictNote,
+  NoteUpdate remoteNote,
+  SyncTitleConflictResolution savedBehavior,
+  SyncTitleConflictResolution resolution,
+  bool noteSyncBitsMatch,
+  Gtk::ResponseType response)
+{
+  auto conflictDlg = static_cast<SyncTitleConflictDialog*>(dialog);
+
+  if(response == Gtk::ResponseType::CANCEL) {
     resolution = CANCEL;
   }
   else {
@@ -636,7 +667,7 @@ void SyncDialog::note_conflict_detected_(
       resolution = OVERWRITE_EXISTING;
     }
     else if(savedBehavior == 0) {
-      resolution = conflictDlg.resolution();
+      resolution = conflictDlg->resolution();
     }
     else {
       resolution = savedBehavior;
@@ -644,25 +675,25 @@ void SyncDialog::note_conflict_detected_(
 
     switch(resolution) {
     case OVERWRITE_EXISTING:
-      if(conflictDlg.always_perform_this_action()) {
+      if(conflictDlg->always_perform_this_action()) {
         savedBehavior = resolution;
       }
       // No need to delete if sync will overwrite
       if(localConflictNote->id() != remoteNote.m_uuid) {
-        m_manager.delete_note(localConflictNote);
+        m_manager.delete_note(*localConflictNote);
       }
       break;
     case RENAME_EXISTING_AND_UPDATE:
-      if(conflictDlg.always_perform_this_action()) {
+      if(conflictDlg->always_perform_this_action()) {
         savedBehavior = resolution;
       }
-      rename_note(localConflictNote, conflictDlg.renamed_title(), true);
+      rename_note(localConflictNote, conflictDlg->renamed_title(), true);
       break;
     case RENAME_EXISTING_NO_UPDATE:
-      if(conflictDlg.always_perform_this_action()) {
+      if(conflictDlg->always_perform_this_action()) {
         savedBehavior = resolution;
       }
-      rename_note(localConflictNote, conflictDlg.renamed_title(), false);
+      rename_note(localConflictNote, conflictDlg->renamed_title(), false);
       break;
     case CANCEL:
       break;
@@ -671,7 +702,7 @@ void SyncDialog::note_conflict_detected_(
 
   m_gnote.preferences().sync_configured_conflict_behavior(static_cast<int>(savedBehavior));
 
-  conflictDlg.hide();
+  conflictDlg->hide();
 
   // Let the SyncManager continue
   m_gnote.sync_manager().resolve_conflict(/*localConflictNote, */resolution);
@@ -700,7 +731,7 @@ void SyncDialog::rename_note(const Note::Ptr & note, Glib::ustring && newTitle,
   //Logger.Debug ("RenameNote: newCompleteContent: " + newCompleteContent);
 
   // We delete and recreate the note to simplify content conflict handling
-  m_manager.delete_note(note);
+  m_manager.delete_note(*note);
 
   // Create note with old XmlContent just in case GetCompleteNoteXml failed
   DBG_OUT("RenameNote: about to create %s", newTitle.c_str());
